@@ -7,7 +7,12 @@ from python_search.exceptions import CommandDoNotMatchException
 from python_search.interpreter.base import BaseInterpreter
 from python_search.interpreter.cmd import CmdInterpreter
 
+
 class FileInterpreter(BaseInterpreter):
+    """
+    Interprets files
+    """
+
     def __init__(self, cmd: Any, context: Context = None):
         self.context = context
         self.cmd = cmd
@@ -34,8 +39,9 @@ class FileInterpreter(BaseInterpreter):
         if file_extension in [".py", ".vim", ".", ".rc", ".yaml", ".yml", ".conf"]:
             return "docker_nvim"
 
-
         if os.path.isdir(self.cmd["file"]):
+            if is_mac():
+                return "open"
             return "nautilus"
 
         if file_extension == ".pdf":
@@ -56,6 +62,7 @@ class FileInterpreter(BaseInterpreter):
             final_cmd["cli_cmd"] = cmd
         else:
             final_cmd["cmd"] = cmd
+            # final_cmd["new-window-non-cli"] = True
 
         return CmdInterpreter(final_cmd, self.context).interpret_default()
 
